@@ -5,7 +5,6 @@ mod in_memory_broadcast_channel;
 pub use in_memory_broadcast_channel::InMemoryBroadcastChannel;
 
 use async_trait::async_trait;
-use deno_core::error::bad_resource_id;
 use deno_core::error::AnyError;
 use deno_core::include_js_files;
 use deno_core::op_async;
@@ -68,10 +67,7 @@ pub fn op_broadcast_unsubscribe<BC: BroadcastChannel + 'static>(
   rid: ResourceId,
   _buf: (),
 ) -> Result<(), AnyError> {
-  let resource = state
-    .resource_table
-    .get::<BC::Resource>(rid)
-    .ok_or_else(bad_resource_id)?;
+  let resource = state.resource_table.get::<BC::Resource>(rid)?;
   let bc = state.borrow::<BC>();
   bc.unsubscribe(&resource)
 }
@@ -81,11 +77,7 @@ pub async fn op_broadcast_send<BC: BroadcastChannel + 'static>(
   (rid, name): (ResourceId, String),
   buf: ZeroCopyBuf,
 ) -> Result<(), AnyError> {
-  let resource = state
-    .borrow()
-    .resource_table
-    .get::<BC::Resource>(rid)
-    .ok_or_else(bad_resource_id)?;
+  let resource = state.borrow().resource_table.get::<BC::Resource>(rid)?;
   let bc = state.borrow().borrow::<BC>().clone();
   bc.send(&resource, name, buf.to_vec()).await
 }
@@ -95,11 +87,7 @@ pub async fn op_broadcast_recv<BC: BroadcastChannel + 'static>(
   rid: ResourceId,
   _buf: (),
 ) -> Result<Option<Message>, AnyError> {
-  let resource = state
-    .borrow()
-    .resource_table
-    .get::<BC::Resource>(rid)
-    .ok_or_else(bad_resource_id)?;
+  let resource = state.borrow().resource_table.get::<BC::Resource>(rid)?;
   let bc = state.borrow().borrow::<BC>().clone();
   bc.recv(&resource).await
 }
@@ -110,7 +98,7 @@ pub fn init<BC: BroadcastChannel + 'static>(
 ) -> Extension {
   Extension::builder()
     .js(include_js_files!(
-      prefix "deno:extensions/broadcast_channel",
+      prefix "deno:ext/broadcast_channel",
       "01_broadcast_channel.js",
     ))
     .ops(vec![
